@@ -6,10 +6,10 @@ Licence: MIT
 """
 
 
-import automl
-import features
-import ml
-import task
+from . import automl
+from . import features
+from . import ml
+from . import task
 
 
 __all__ = [
